<?php
/**
 * Created by PhpStorm.
 * User: RSkaldin
 * Date: 6/3/2019
 * Time: 1:33 AM
 */

namespace App\Http\Controllers\Postman;

use App\Http\Controllers\Controller;
use App\Models\Activity;
use App\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;

class UsersController extends Controller {

    /**
     * List of users
     * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
     */
    public function index()
    {
        $users = User::orderBy('id', 'DESC')->paginate(25);
        return view('pages.admin.users.user_list', ['users' => $users]);
    }

    /**
     * View or edit a user
     * @param $user_id
     * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
     */
    public function edit($user_id)
    {
        return view('pages.admin.users.edit', ['user' => User::find($user_id)]);
    }

    /**
     * Update user information
     * @param $user_id
     * @param Request $request
     * @return \Illuminate\Http\RedirectResponse
     */
    public function update($user_id, Request $request)
    {
        try {
            if (($user = User::find($user_id)) == null)
                throw new \Exception('User not found.');

            if (!$request->filled('password'))
                throw new \Exception('Password can not be empty.');

            if ($request->input('password') !== $request->input('password_confirmation'))
                throw new \Exception('Confirmation password is incorrect.');

            $user->name = $request->input('name');
            $user->email = $request->input('email');
            $user->firstname = $request->input('firstname');
            $user->lastname = $request->input('lastname');
            $user->phone = $request->input('phone');
            $user->password = Hash::make($request->input('password'));
            if (!$user->save())
                throw new \Exception('Ошибка сохранения модели User');

        } catch (\Exception $ex) {
            Activity::appendLog('Ошибка редактирования пользователя: '.$ex->getMessage(), Activity::ERROR);
            return redirect()->back()->with(['error' => $ex->getMessage()]);
        }

        Activity::appendLog('Информация о пользователе успешно обновлена', Activity::SUCCESS);
        return redirect()->back()->with(['success' => 'Информация успешно сохранена.']);
    }
}